@@ -3,6 +3,7 @@ import os
 import numpy as np
 import warnings
 from osgeo import gdal
+from datetime import datetime
 
 warnings.filterwarnings('ignore')
 
@@ -31,25 +32,19 @@ def merge_clip_raster(raster_file_list, output_file=None, shp_file=None, bbox=No
     for raster in raster_file_list:
         ds = gdal.Warp('', raster, format='vrt', dstNodata=0,
                        dstSRS="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0",
-                       cutlineDSName=shp_file, cropToCutline=True)
+                       cutlineDSName=shp_file, cropToCutline=True, width=out_width, height=out_height)
         ds_lst.append(ds)
     del ds
     if shp_file:
         ds = gdal.BuildVRT('', ds_lst, VRTNodata=0, srcNodata=0)
         gdal.Warp(output_file, ds, format='GTiff', dstNodata=0,
                   dstSRS="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0",
-                  cutlineDSName=shp_file, cropToCutline=True)
+                  cutlineDSName=shp_file, cropToCutline=True, width=out_width, height=out_height)
     else:
-        if out_width:
-            ds = gdal.BuildVRT('', ds_lst, VRTNodata=0, srcNodata=0)
-            gdal.Warp(output_file, ds, format='GTiff', dstNodata=0,
-                      dstSRS="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0",
-                      outputBounds=tuple(bbox), cropToCutline=True, width=out_width, height=out_height)
-        else:
-            ds = gdal.BuildVRT('', ds_lst, VRTNodata=0, srcNodata=0)
-            gdal.Warp(output_file, ds, format='GTiff', dstNodata=0,
-                      dstSRS="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0",
-                      outputBounds=tuple(bbox), cropToCutline=True)
+        ds = gdal.BuildVRT('', ds_lst, VRTNodata=0, srcNodata=0)
+        gdal.Warp(output_file, ds, format='GTiff', dstNodata=0,
+                  dstSRS="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0",
+                  outputBounds=tuple(bbox), cropToCutline=True, width=out_width, height=out_height)
     return output_file
 
 
@@ -76,4 +71,9 @@ def raster_mosaic(raster_list, output_file):
     ds = gdal.BuildVRT('', raster_list, separate=True)
     gdal.Translate(output_file, ds)
     del ds
-    return output_file
\ No newline at end of file
+    return output_file
+
+
+def date_config(s_date, e_date):
+    s_date = datetime.strptime(s_date, '%Y-%M-%d')
+    e_date = datetime.strptime(e_date, '%Y-%M-%d')
